package online.wesal.wesal.repository;

import online.wesal.wesal.entity.Attendee;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.stereotype.Repository;
import java.util.List;

@Repository
public interface AttendeeRepository extends JpaRepository<Attendee, Long> {
    
    boolean existsByInvitationIdAndUserId(Long invitationId, Long userId);
    
    List<Attendee> findByInvitationId(Long invitationId);
    
    void deleteByInvitationId(Long invitationId);
    
    void deleteByInvitationIdAndUserId(Long invitationId, Long userId);
}